@@ -4,9 +4,10 @@ from functools import lru_cache
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
+from fuzzing_cli.fuzz.config import FuzzingOptions
 from fuzzing_cli.fuzz.exceptions import BuildArtifactsError
-from fuzzing_cli.fuzz.ide.generic import Contract, IDEArtifacts, Source
-from fuzzing_cli.fuzz.options import FuzzingOptions
+from fuzzing_cli.fuzz.ide.generic import IDEArtifacts
+from fuzzing_cli.fuzz.types import Contract, Source
 from fuzzing_cli.util import get_content_from_file
 
 LOGGER = logging.getLogger("fuzzing-cli")
@@ -16,15 +17,13 @@ class BrownieArtifacts(IDEArtifacts):
     def __init__(
         self,
         options: FuzzingOptions,
+        build_dir: Path,
+        sources_dir: Path,
         targets: Optional[List[str]] = None,
-        build_dir: Optional[Path] = None,
         map_to_original_source: bool = False,
     ):
         super(BrownieArtifacts, self).__init__(
-            options,
-            targets,
-            build_dir or Path("./build/contracts"),
-            map_to_original_source,
+            options, targets, build_dir, sources_dir, map_to_original_source
         )
 
     @classmethod
@@ -38,12 +37,12 @@ class BrownieArtifacts(IDEArtifacts):
         return "brownie-config.yaml" in files
 
     @staticmethod
-    def get_default_build_dir() -> str:
-        return "build/contracts"
+    def get_default_build_dir() -> Path:
+        return Path.cwd().joinpath("build/contracts")
 
     @staticmethod
-    def get_default_sources_dir() -> str:
-        return "contracts"
+    def get_default_sources_dir() -> Path:
+        return Path.cwd().joinpath("contracts")
 
     @property
     def contracts(self) -> List[Contract]:
@@ -66,10 +65,12 @@ class BrownieArtifacts(IDEArtifacts):
             if len(component) < 3 or component[2] == "":
                 continue
             allFileIds.add(component[2])
-        return [int(fileId) for fileId in allFileIds if fileId not in sources.keys()]
+        return sorted(
+            [int(fileId) for fileId in allFileIds if fileId not in sources.keys()]
+        )
 
     @lru_cache(maxsize=1)
-    def fetch_data(self) -> Tuple[List[Contract], Dict[str, Source]]:
+    def process_artifacts(self) -> Tuple[Dict[str, List[Contract]], Dict[str, Source]]:
         """ example build_files_by_source_file
             {
                 'contracts/Token.sol':
@@ -87,8 +88,6 @@ class BrownieArtifacts(IDEArtifacts):
 
         # ( 'contracts/Token.sol', {'allSourcePaths':..., 'deployedSourceMap': ... } )
         for source_file, contracts in build_files_by_source_file.items():
-            if source_file not in self._include:
-                continue
             result_contracts[source_file] = []
             for contract in contracts:
                 # We get the build items from brownie and rename them into the properties used by the FaaS
@@ -139,4 +138,4 @@ class BrownieArtifacts(IDEArtifacts):
                         result_sources[source_file_dep][
                             "source"
                         ] = get_content_from_file(source_file_dep + ".original")
-        return self.flatten_contracts(result_contracts), result_sources
+        return result_contracts, result_sources
